@@ -24,4 +24,14 @@ def mapNumberToSaturation(
     iPol = np.interp(num, numLims, satLims)
     kCol = Color(hex=colorHex)
     kOut = Color(hsv=(kCol.hsv[0], iPol, kCol.hsv[1]))
-    return kOut.hex
\ No newline at end of file
+    return kOut.hex
+
+
+def align_yaxis(ax1, v1, ax2, v2):
+    """adjust ax2 ylimit so that v2 in ax2 is aligned to v1 in ax1"""
+    _, y1 = ax1.transData.transform((0, v1))
+    _, y2 = ax2.transData.transform((0, v2))
+    inv = ax2.transData.inverted()
+    _, dy = inv.transform((0, 0)) - inv.transform((0, y1-y2))
+    miny, maxy = ax2.get_ylim()
+    ax2.set_ylim(miny+dy, maxy+dy)
\ No newline at end of file
